static char *rcsid="$Id: stdutil.c,v 1.11 1997/11/16 21:54:53 nneul Exp $";

/**
 **  File: stdutil.c
 **  Purpose: Home grown alternatives for routines not in standard library
 **/
 
#include "cgiwrap.h"	/* Headers for all CGIwrap source files */

/*
 * strdup() - copy a string into a newly allocated block of memory
 */
#if !defined(HAS_STRDUP)
char *strdup(char *str)
{
	char *temp;

	temp = (char *) malloc ( strlen(str) + 1 );
	if (!temp)
	{
		MSG_Error_SystemError("Couldn't malloc memory for string!");
	}
	strcpy(temp,str);

	return temp;
}
#endif

